@@ -22,23 +22,22 @@ import           TestSuite.Util
 
 --------------------------------------------------------------------------------
 tests :: TestTree
-tests = testGroup "Hakyll.Core.UnixFilter.Tests"
+tests = testGroup "Hakyll.Core.UnixFilter.Tests" $
 #ifdef mingw32_HOST_OS
-    -- The `rev` utility is not present by default on Windows
+    [] -- The `rev` utility is not present by default on Windows
+#else
+    [ testCase "unixFilter rev"   unixFilterRev ]
+#endif
+    ++
     [ testCase "unixFilter false" unixFilterFalse
     , testCase "unixFilter error" unixFilterError
     ]
-#else
-    [ testCase "unixFilter rev"   unixFilterRev
-    , testCase "unixFilter false" unixFilterFalse
-    , testCase "unixFilter error" unixFilterError
-    ]
-#endif
 
 testMarkdown :: Identifier
 testMarkdown = "russian.md"
 
 --------------------------------------------------------------------------------
+#ifndef mingw32_HOST_OS
 unixFilterRev :: H.Assertion
 unixFilterRev = do
     store    <- newTestStore
@@ -50,6 +49,7 @@ unixFilterRev = do
   where
     compiler = getResourceString >>= withItemBody (unixFilter "rev" [])
     rev      = map reverse . lines
+#endif
 
 
 --------------------------------------------------------------------------------
